# Project Tangerine

- [X] acquire trebuchet plans
- [X] source counterweight materials
- [X] build it
- [#] throw fruit at neighbours (they moved away)

```
This isn't worth doing, the neighbours have already moved away.

# Mangonel

- [ ] acquire mangonel plans

```
